==> latte-dock-0.7.2.tar.xz: latte-dock-0.7.2/applets/spacer/metadata.desktop.cmake <==
[Desktop Entry]
Name=Latte Dock Spacer
Name[ca]=Espaiador pel Latte Dock
Name[ca@valencia]=Espaiador pel Latte Dock
Name[de]=Latte-Dock Abstandshalter
Name[el]=Διαχωριστικό Latte
Name[es]=Separador de Latte Dock
Name[nl]=Latte Dock paneelscheider
Name[pl]=Wypełniacz doku Latte
Name[pt]=Espaço da Área Acoplável do Latte
Name[sv]=Avskiljare för Latte dockningsfönster
Name[uk]=Розпірка панелі Латте
Name[x-test]=xxLatte Dock Spacerxx
Name[zh_TW]=Latte Dock 間隔器
Comment=Reserve empty spaces within the dock.
Comment[ca]=Reserva espais buits dins de l'acoblador.
Comment[ca@valencia]=Reserva espais buits dins de l'acoblador.
Comment[de]=Macht Platz in der Leiste
Comment[el]=Διατηρεί κενούς χώρους μέσα στον πίνακα.
Comment[es]=Reservar espacios en blanco en el dock.
Comment[nl]=Reserveer lege ruimte in het dok.
Comment[pl]=Zajmij puste powierzchnie w doku.
Comment[pt]=Reservar espaços em branco dentro da área acoplável.
Comment[sv]=Reservera tomt utrymme inne i dockningsfönstret.
Comment[uk]=Створює прогалини на панелі.
Comment[x-test]=xxReserve empty spaces within the dock.xx
Comment[zh_TW]=在 dock 中保留空間。

Encoding=UTF-8
Type=Service
Keywords=spacer
Keywords[ca]=espaiador
Keywords[ca@valencia]=espaiador
Keywords[de]=Abstandshalter
Keywords[el]=κενό
Keywords[es]=separador
Keywords[nl]=paneelscheider
Keywords[pl]=wypełniacz
Keywords[pt]=espaço
Keywords[sv]=mellanrum
Keywords[uk]=розпірка
Keywords[x-test]=xxspacerxx
Keywords[zh_TW]=空白
NoDisplay=true


X-Plasma-API=declarativeappletscript
X-Plasma-MainScript=ui/main.qml
X-KDE-ServiceTypes=Plasma/Applet
X-KDE-PluginInfo-Author=Michail Vourlakos
X-KDE-PluginInfo-Email=mvourlakos@gmail.com
X-KDE-PluginInfo-Name=org.kde.latte.spacer
X-KDE-PluginInfo-Version=0.1
X-KDE-PluginInfo-Website=https://github.com/psifidotos/Latte-Dock/
X-KDE-PluginInfo-Category=System Information
X-KDE-PluginInfo-Depends=X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-EnabledByDefault=true

==> latte-dock-0.7.3.tar.xz: latte-dock-0.7.3/applets/spacer/metadata.desktop.cmake <==
[Desktop Entry]
Name=Latte Dock Spacer
Name[ca]=Espaiador pel Latte Dock
Name[ca@valencia]=Espaiador pel Latte Dock
Name[da]=Afstandsstykke til Latte-dok
Name[de]=Latte-Dock Abstandshalter
Name[el]=Διαχωριστικό Latte
Name[en_GB]=Latte Dock Spacer
Name[es]=Separador de Latte Dock
Name[it]=Spaziatore Latte Dock
Name[nl]=Latte Dock paneelscheider
Name[pl]=Wypełniacz doku Latte
Name[pt]=Espaço da Área Acoplável do Latte
Name[sv]=Avskiljare för Latte dockningsfönster
Name[uk]=Розпірка панелі Латте
Name[x-test]=xxLatte Dock Spacerxx
Name[zh_TW]=Latte Dock 間隔器
Comment=Reserve empty spaces within the dock.
Comment[ca]=Reserva espais buits dins de l'acoblador.
Comment[ca@valencia]=Reserva espais buits dins de l'acoblador.
Comment[da]=Reservér tomme pladser i dokken.
Comment[de]=Macht Platz in der Leiste
Comment[el]=Διατηρεί κενούς χώρους μέσα στον πίνακα.
Comment[en_GB]=Reserve empty spaces within the dock.
Comment[es]=Reservar espacios en blanco en el dock.
Comment[it]=Riserva spazi vuoti all'interno dell'area di aggancio.
Comment[nl]=Reserveer lege ruimte in het dok.
Comment[pl]=Zajmij puste powierzchnie w doku.
Comment[pt]=Reservar espaços em branco dentro da área acoplável.
Comment[sv]=Reservera tomt utrymme inne i dockningsfönstret.
Comment[uk]=Створює прогалини на панелі.
Comment[x-test]=xxReserve empty spaces within the dock.xx
Comment[zh_TW]=在 dock 中保留空間。

Encoding=UTF-8
Type=Service
Keywords=spacer
Keywords[ca]=espaiador
Keywords[ca@valencia]=espaiador
Keywords[da]=afstandsstykke
Keywords[de]=Abstandshalter
Keywords[el]=κενό
Keywords[en_GB]=spacer
Keywords[es]=separador
Keywords[it]=spaziatore
Keywords[nl]=paneelscheider
Keywords[pl]=wypełniacz
Keywords[pt]=espaço
Keywords[sv]=mellanrum
Keywords[uk]=розпірка
Keywords[x-test]=xxspacerxx
Keywords[zh_TW]=空白
NoDisplay=true


X-Plasma-API=declarativeappletscript
X-Plasma-MainScript=ui/main.qml
X-KDE-ServiceTypes=Plasma/Applet
X-KDE-PluginInfo-Author=Michail Vourlakos
X-KDE-PluginInfo-Email=mvourlakos@gmail.com
X-KDE-PluginInfo-Name=org.kde.latte.spacer
X-KDE-PluginInfo-Version=0.1
X-KDE-PluginInfo-Website=https://github.com/psifidotos/Latte-Dock/
X-KDE-PluginInfo-Category=System Information
X-KDE-PluginInfo-Depends=X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-EnabledByDefault=true
